.TH "G4_CMD_BLOCK_STRUCT" "3" "1" "Polhemus" "Polhemus G4Track Library"
.SH "NAME"
G4_CMD_BLOCK_STRUCT \- Block Configuration Structure
.SH "SYNOPSIS"
#include "G4TrackIncl.h"
.br 


typedef struct _G4_CMD_BLOCK_STRUCT {
.br 
	int \fIunits\fR[2];			// pos, att
.br 
	uint8_t \fIversion_info\fR[50];
.br 
	float \fIfilter_params\fR[2][4];	// pos,att
.br 
	float \fIincrement\fR[G4_SENSORS_PER_HUB][2];		// pos, att
.br 
	float \fIrot_angles\fR[3];	// az, el, rl
.br 
	float \fItranslate_xyz\fR[3];
.br 
	float \fItip_offset\fR[G4_SENSORS_PER_HUB][3];
.br 
}\fB*LPG4_CMD_BLOCK_STRUCT,G4_CMD_BLOCK_STRUCT\fR;
.SH "DESCRIPTION"
This structure is used only when the \fBG4_CMD_BLOCK_CFG\fR command is used with the \fBg4_set_query\fR() function.  It can be used to set or read many configurations at once rather than in a one\-at\-a\-time sequence.  A pointer to this structure would be passed into the \fIpParam\fR variable of the \fBG4_CMD_DATA_STRUCT\fR structure when using the block read/write command.
.SH "STRUCTURE MEMBERS"
\fIunits\fR:  An array of two ints that correspond to the position and orientation units.  If setting, the system units will be set to the values contained in this array, if getting, the values in this array will be set to the current system units.  See documentation on \fBG4_CMD_UNITS\fR under \fBg4_set_query\fR().
.br 

\fIversion_info\fR:  Get only.  The system version information will be copied here.  See documentation on \fBG4_CMD_WHOAMI\fR under \fBg4_set_query\fR().
.br 

\fIfilter_params\fR:  Two arrays of four elements each.  The first is for the position filter values, the second is for the orientation filter values.  If setting the system filters will be set to these values, if getting these values will be set to current system filter values.  See documentation on \fBG4_CMD_FILTER\fR under \fBg4_set_query\fR().
.br 

\fIincrement\fR:  An array of two elements for each sensor on a hub.  One is for the positional increment value, the second for the orientation increment value.  See documentation for \fBG4_CMD_INCREMENT\fR under \fBg4_set_query\fR().
.br 

\fIrot_angles\fR:  An array of three floats that will either set or return the frame\-of\-reference rotation values of the system.  These values correspond to Azimuth (Yaw), Elevation (Pitch), and Roll respectively.  See documentation for \fBG4_CMD_FOR_ROTATE\fR under \fBg4_set_query\fR().
.br 

\fItranslate_xyz\fR: An array of three float that will either set or return the frame\-of\-reference translation values of the system.  These values correspond to the X, Y, and Z values of the translation respectively.  See documentation for \fBG4_CMD_FOR_TRANSLATE\fR under \fBg4_set_query\fR().
.br 

\fItip_offset\fR:  An array of three floats for each sensor on the hub.  These values correspond to the X, Y, and Z values of the offset respectively.  See documentation for \fBG4_CMD_TIP_OFFSET\fR under \fBg4_set_query\fR().

.SH "AUTHOR"
James C. Farr <jimfarr@polhemus.com>
.SH "SEE ALSO"
\fBg4_init_sys\fR(3), \fBg4_set_query\fR(3), \fBg4_get_frame_data\fR(3), \fBg4_close_tracker\fR(3), \fBG4Track\fR(3), \fBG4_SENFRAMEDATA\fR(3), \fBG4_CMD_DATA_STRUCT\fR(3), \fBG4_CMD_STRUCT\fR(3), \fBG4_SRC_MAP\fR(3), \fBG4_FRAMEDATA\fR(3)
